@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -147,6 +147,8 @@ void add_user(struct w *widgets)
     G_CONST_RETURN gchar *group;
     G_CONST_RETURN gchar *comment;
     G_CONST_RETURN gchar *shell;
+    G_CONST_RETURN gchar *login_from;
+    G_CONST_RETURN gchar *max_logins;
     G_CONST_RETURN gchar *br=NULL, *brc=NULL, *fr=NULL, *frc=NULL;
 
     username  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[0]));
@@ -162,6 +164,9 @@ void add_user(struct w *widgets)
      * This is done so that no user gets sshd/etc access unless the admin wants to.
      */
 
+    login_from = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[5]));
+    max_logins = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[0]));
+
     /* Ratios */
     if( use_ratio )
     {
@@ -495,7 +500,7 @@ void add_user(struct w *widgets)
 	make_dir_chmod((gchar *)restricted_dir, "0777"); /* Must be like this */
 
 	/* Add a block all .ftpaccess file to this directory */
-	cmd = g_strdup_printf("echo \"DenyAll\n\" > %s/.ftpaccess", restricted_dir);
+	cmd = g_strdup_printf("echo \"DenyAll\n\" > '%s/.ftpaccess'", restricted_dir);
 	if( ! run_command(cmd) )    
 	{
 	    printf("Error creating .ftpaccess file here: %s/.ftpaccess\n", restricted_dir);
@@ -504,7 +509,7 @@ void add_user(struct w *widgets)
 	g_free(cmd);
 
 	/* Add the ratio files */
-	cmd = g_strdup_printf("touch %s/proftpd_ratios %s/proftpd_ratios_temp", restricted_dir, restricted_dir);
+	cmd = g_strdup_printf("touch '%s/proftpd_ratios' '%s/proftpd_ratios_temp'", restricted_dir, restricted_dir);
 	if( ! run_command(cmd) )    
 	{
 	    printf("Error creating the ratio files here: %s\n", restricted_dir);
@@ -513,7 +518,7 @@ void add_user(struct w *widgets)
 	g_free(cmd);
     
 	/* Chmod a+rw on the ratio files (must be a+rw) */
-	cmd = g_strdup_printf("chmod a+rw %s/proftpd_ratios %s/proftpd_ratios_temp", restricted_dir, restricted_dir);
+	cmd = g_strdup_printf("chmod a+rw '%s/proftpd_ratios' '%s/proftpd_ratios_temp'", restricted_dir, restricted_dir);
 	if( ! run_command(cmd) )    
 	{
 	    printf("Error chmodding the ratio files here: %s\n", restricted_dir);
@@ -522,7 +527,7 @@ void add_user(struct w *widgets)
 	g_free(cmd);
 
 	/* Chown ratio files to SERVERUSER:SERVERGROUP */
-	cmd = g_strdup_printf("chown %s:%s %s/proftpd_ratios %s/proftpd_ratios_temp", SERVER_USER, SERVER_GROUP, restricted_dir, restricted_dir);
+	cmd = g_strdup_printf("chown %s:%s '%s/proftpd_ratios' '%s/proftpd_ratios_temp'", SERVER_USER, SERVER_GROUP, restricted_dir, restricted_dir);
 	if( ! run_command(cmd) )    
 	{
 	    printf("Error chmodding the ratio files here: %s\n", restricted_dir);
@@ -533,8 +538,6 @@ void add_user(struct w *widgets)
 	g_free(restricted_dir);
     }    
 
-
-
     /* The users configuration profile */
     strcpy(user_profile, "\n<Anonymous ");
     strcat(user_profile, homedir);
@@ -544,15 +547,22 @@ void add_user(struct w *widgets)
     strcat(user_profile, "\nGroup ");
     strcat(user_profile, group);
     strcat(user_profile, "\n");
-    strcat(user_profile, "AnonRequirePassword on\n");
-    strcat(user_profile, "MaxClients 10 \"The server is full, hosting %m users\"\n");
-    strcat(user_profile, "DisplayLogin welcome.msg\n");
 
-    /* Fix for a changed directive, sorry Fedora backported... */
-//    if( strstr(global_version, "1.2.") || strstr(global_version, "1.3.0") )
-//      strcat(user_profile, "DisplayFirstChdir .msg\n");
-//    else
-//      strcat(user_profile, "DisplayChdir .msg\n");
+    /* Require password */
+    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[1])) )
+      strcat(user_profile, "AnonRequirePassword off\n");
+    else
+      strcat(user_profile, "AnonRequirePassword on\n");
+
+    /* Maximum logins */
+    strcat(user_profile, "MaxClients ");
+    strcat(user_profile, max_logins);
+    strcat(user_profile, " \"");
+    strcat(user_profile, "The server is full, hosting %m users");
+    strcat(user_profile, "\"\n");
+
+    strcat(user_profile, "DisplayLogin welcome.msg\n");
+    strcat(user_profile, "DisplayChdir .msg\n");
       
     /* Ratio Module (reversed br/fr order in the gui) */
     if( use_ratio )
@@ -570,13 +580,25 @@ void add_user(struct w *widgets)
         strcat(user_profile, "\n");
     }
 
-    strcat(user_profile, "<Limit LOGIN>\n");
-    strcat(user_profile, " Allow from all\n");
-    strcat(user_profile, " Deny from all\n");
-    strcat(user_profile, "</Limit>\n");
-    strcat(user_profile, "AllowOverwrite off\n");
+    /* Logins from, if nothing is specified we allow everything */
+    if( login_from == NULL || strlen(login_from) < 3 )
+    {
+	strcat(user_profile, "<Limit LOGIN>\n");
+        strcat(user_profile, "Allow from all\nDeny from all\n");
+        strcat(user_profile, "</Limit>\n");
+    }
+    else
+    {
+	strcat(user_profile, "<Limit LOGIN>\n");
+	strcat(user_profile, "Allow from ");
+	strcat(user_profile, login_from);
+	strcat(user_profile, "\nDeny from all\n");
+	strcat(user_profile, "</Limit>\n");
+    }
+
+
+    append_limit_cmds(); /* Also adds AllowOverwrite on/off */
 
-    append_limit_cmds();
 
     row_pos = 1; /* Append and create the rest of the directories */
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) dirs_foreach, widgets);
