@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,7 @@ extern int row_pos;
 char *user_profile;
 
 
+/* Check if the user exists in the selected server */
 int user_exists_in_selected_server(struct w *widgets, gchar *username)
 {
     FILE *fp;
@@ -64,15 +65,9 @@ int user_exists_in_selected_server(struct w *widgets, gchar *username)
     char *line, *user_check;
     char *address_buffer, *port_buffer;
     int found_server=0, standard_server=0;
-    gchar *info;
 
-    /* Check if the user exists in the selected server */
     if((fp=fopen(PROFTPD_CONF,"r"))==NULL)
     {
-//	info = g_strdup_printf(_("Failed adding user: %s\nCant open proftpd.conf.\n"), username);
-//	show_info(info);
-//	g_free(info);
-
     	return 0;
     }
     fseek(fp, 0, SEEK_END);
@@ -122,10 +117,6 @@ int user_exists_in_selected_server(struct w *widgets, gchar *username)
     /* The selected vhost was not found */
     if( ! standard_server && ! found_server )
     {
-//	info = g_strdup_printf(_("Failed adding user: %s\nThe selected virtual host was not found.\n"), username);
-//	show_info(info);
-//	g_free(info);
-
 	fclose(fp);
 	free(user_check);
 	free(line);
@@ -145,10 +136,6 @@ int user_exists_in_selected_server(struct w *widgets, gchar *username)
 	&& ! strstr(line, "AllowUser")
 	&& ! strstr(line, "FakeUser")    )
 	{
-//	    info = g_strdup_printf(_("Failed adding user: %s\nThe user already exists in this server.\n"), username);
-// 	    show_info(info);
-//	    g_free(info);
-
 	    fclose(fp);
 	    free(user_check);
 	    free(line);
@@ -248,10 +235,7 @@ void apply_user(struct w *widgets)
     if( ! user_exists_in_selected_server(widgets, (gchar *)username) )
     {
 	/* Add a new user */
-	printf("This user does not exist, adding it...\n");
-
 	add_user(widgets);
-
         return;
     }
 
@@ -296,12 +280,7 @@ void apply_user(struct w *widgets)
 
     /* Static Welcome and chdir msgs */
     strcat(user_profile, "DisplayLogin welcome.msg\n");
-
-//  Fedora backported all but this!
-//    if( strstr(global_version, "1.2.") || strstr(global_version, "1.3.0") ) 
-//      strcat(user_profile, "DisplayFirstChdir .msg\n");
-//    else
-//      strcat(user_profile, "DisplayChdir .msg\n");
+    strcat(user_profile, "DisplayChdir .msg\n");
 
     /* Ratio Module (reversed br/fr order in the gui) */
     if( use_ratio )
@@ -450,10 +429,10 @@ void apply_user(struct w *widgets)
 			if( strstr(line, "<Anonymous") )
 			  break;
 
-			if( strstr(line, "</VirutalHost") )
+			if( strstr(line, "</VirtualHost") )
 			  break;
 
-			if( strstr(line, "<VirutalHost") )
+			if( strstr(line, "<VirtualHost") )
 			  break;
 		    }
 		}
