@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ void create_import_window(struct w *widgets)
     GtkTreeIter iter;
     GtkTreeSelection *selection;
     gchar *utf8=NULL;
-    gchar *username, *groupname; //, *what, *val;
+    gchar *username, *groupname;
     GtkTreeViewColumn *user_col, *group_col;
     GtkCellRenderer *import_cell_renderer;
     GtkWidget *import_vbox;
