@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,9 +66,11 @@ void append_limit_cmds()
 {
     int i = 0, has_limit = 0;
 
-    /* Overwrite selected, add "Allowoverwrite on" before the directory limits */    
+    /* Set AllowOverwrite before the directory limits */
     if( dir_val[6] )
       strcat(user_profile, "AllowOverwrite on\n");
+    else
+      strcat(user_profile, "AllowOverwrite off\n");
     
     /* ALLOW CMDs. Iter the 18 checkboxes */
     strcat(user_profile, "<Limit");
