@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -825,7 +825,7 @@ void make_dir_chmod(gchar *directory, char perm[128])
 {
     gchar *command;
     
-    command = g_strdup_printf("mkdir -p %s && chmod %s %s", directory, perm, directory);
+    command = g_strdup_printf("mkdir -p '%s' && chmod %s '%s'", directory, perm, directory);
     if( ! run_command(command) )
       printf("Error running command: %s\n", command);    
 
