@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,20 +53,9 @@ extern char global_version[1024];
 
 /* Fixme: Set at import_button_pressed */ 
 char import_root_dir[8192]="";
-//int import_to_usernamed_dirs = 0;
 long num_imported = 0;
 
 
-/*
-void import_namebased_checkbutton_toggled(GtkToggleButton *togglebutton, struct w *widgets)
-{
-    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)) )
-      import_to_usernamed_dirs = 1;
-    else
-      import_to_usernamed_dirs = 0;
-}
-*/
-
 void add_import_users(GtkTreeModel *model, GtkTreePath *path,
 		         GtkTreeIter *iter, struct w *widgets)
 {
@@ -284,13 +273,7 @@ void add_import_users(GtkTreeModel *model, GtkTreePath *path,
     strcat(user_settings, "AnonRequirePassword on\n");
     strcat(user_settings, "MaxClients 3 \"The server is full, hosting %m users\"\n");
     strcat(user_settings, "DisplayLogin welcome.msg\n");
-
-//  Sorry, Fedora backported but forgot this ?
-//    if( strstr(global_version, "1.2.") || strstr(global_version, "1.3.0") )
-//      strcat(user_settings, "DisplayFirstChdir .msg\n");
-//    else
-//      strcat(user_settings, "DisplayChdir .msg\n");
-
+    strcat(user_settings, "DisplayChdir .msg\n");
     strcat(user_settings, "AllowOverwrite off\n");
     strcat(user_settings, "<Limit LOGIN>\n");
     strcat(user_settings, " Allow from all\n");
