@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ void populate_users(struct w *widgets)
     GtkTreePath *path;
     GtkTreeModel *list_store;
     char *old_buffer, *new_buffer, *address_buffer, *port_buffer, *translate;
-    long conf_size;
+    long i=0, conf_size=0;
     gboolean edit=0;
     int found_user=0, found_server=0;
     gchar *user, *user_comment;
@@ -135,12 +135,26 @@ void populate_users(struct w *widgets)
 	{
 	    /* Insert directory */
 	    found_user = 1;
-	    sscanf(old_buffer, "%*s %s", new_buffer);
-	    new_buffer[strlen(new_buffer)-1]='\0';
+
+	    /* Scroll to the beginning of the directory path */
+	    for(i=0; old_buffer[i]!='\0'; i++)
+		if( old_buffer[i]!=' ' )
+		  break;
+	    for(i=i; old_buffer[i]!='\0'; i++)
+		if( old_buffer[i]==' ' && old_buffer[i+1]!=' ' )
+		  break;
+
+	    snprintf(new_buffer, conf_size, "%s", &old_buffer[i+1]);
+
+	    /* Cut at path end */
+	    for(i=0; new_buffer[i]!='\0'; i++)
+		if( new_buffer[i]=='>' )
+		  break;
+	    new_buffer[i]='\0';
+
     	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
     	    gtk_list_store_append(GTK_LIST_STORE(widgets->user_store), &iter);
     	    gtk_list_store_set(GTK_LIST_STORE(widgets->user_store), &iter, 3, utf8, -1);
-	    
 
     	    while(fgets(old_buffer, conf_size, fp)!=NULL)
     	    {
@@ -151,10 +165,6 @@ void populate_users(struct w *widgets)
     		    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
     		    gtk_list_store_set(GTK_LIST_STORE(widgets->user_store), &iter, 0, utf8, -1);
 
-// new
-		    /* Set the global username */
-//		    snprintf(global_user_name, 1000, "%s", new_buffer);
-
 		    /* Insert user comment */
 		    user_comment = get_user_setting(new_buffer, "comment");
     		    utf8 = g_locale_to_utf8(user_comment, strlen(user_comment), NULL, NULL, NULL);
