@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,8 +39,6 @@
 extern char global_version[1024];
 
 
-/* Temporary configuration alteration.
-   Keep until dists have released version 0.5.0 */
 void new_tls_module_conf()
 {
     FILE *fp;
@@ -67,6 +65,7 @@ void new_tls_module_conf()
     "TLSRSACertificateKeyFile ", GP_APPCONFDIR, "/certs/key.pem\n",
     "TLSCACertificateFile ", GP_APPCONFDIR, "/certs/cacert.pem\n",
     "TLSRenegotiate required off\n",
+    "TLSOptions AllowClientRenegotiation\n",
     "</IfModule>\n",
     NULL);
 
@@ -273,10 +272,7 @@ void restore_configuration(struct w *widgets)
 
     /* conf_ok() also checks that the configuration lines have valid length */
 
-printf("EEK: %s\n", path);
-
-    if( path!=NULL && strlen(path) > 8
-    &&  conf_ok(path) ) //&& strstr(path, "proftpd.conf") )
+    if( path!=NULL && strlen(path) > 8 && conf_ok(path) )
     {
 	cmd = g_strdup_printf("cp %s %s", path, PROFTPD_CONF);
 	if( ! run_command(cmd) )
@@ -388,6 +384,7 @@ void add_standard_conf(struct w *widgets)
     "TLSRSACertificateKeyFile ", GP_APPCONFDIR, "/certs/key.pem\n",
     "TLSCACertificateFile ", GP_APPCONFDIR, "/certs/cacert.pem\n",
     "TLSRenegotiate required off\n",
+    "TLSOptions AllowClientRenegotiation\n",
     "</IfModule>\n\n",
 
     "<IfModule mod_ratio.c>\n",
