@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -127,10 +127,13 @@ int status_update(struct w *widgets)
         info = g_strdup_printf(_("The server is deactivated.\n"));
 	utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
-	g_free(info);
+	if( info!=NULL )
+	  g_free(info);
 	if( utf8!=NULL )
 	  g_free(utf8);
 
+	free(pid);
+
 	return (TRUE);
     }
     else
@@ -147,11 +150,12 @@ int status_update(struct w *widgets)
 	gdk_color_parse("dark green", &color);
 	gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);
       }
+
     free(pid);
 
     /* The server is activated, insert ftpwho information in the treeview */
 
-    /* Add the scoreboard file if its missing to avoid useless message */
+    /* Add the scoreboard file if its missing to avoid missing message's */
     path = g_strdup_printf("%s/%s", GP_VARDIR, "run/proftpd");
     if( file_exists(path) )
     {
@@ -195,7 +199,8 @@ int status_update(struct w *widgets)
 	utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
         g_free(cmd);
-	g_free(info);
+	if( info!=NULL )
+	  g_free(info);
 	if( utf8!=NULL )
 	  g_free(utf8);
 	
@@ -345,10 +350,24 @@ int status_update(struct w *widgets)
 	    if( utf8!=NULL )
 	      g_free(utf8);
 	}
+	/* Insert directory path */
 	if( strstr(line, "location: ") )
 	{
-	    /* Insert directory location */
-	    sscanf(line, "%*s %s", tmp);
+	    /* Scroll to the beginning of the path */
+	    for(i=0; line[i]!='\0' && i<16384; i++)
+	      if( line[i]!=' ' )
+	        break;
+	    for(i=i; line[i]!='\0' && i<16384; i++)
+	      if( line[i]==' ' )
+	        break;
+	    for(i=i; line[i]!='\0' && i<16384; i++)
+	      if( line[i]!=' ' )
+	        break;
+
+	    snprintf(tmp, 16384, "%s", &line[i]);
+	    if( tmp[strlen(tmp)-1]=='\n' )
+        	tmp[strlen(tmp)-1]='\0';
+
 	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
 	    gtk_list_store_set(GTK_LIST_STORE(widgets->transfer_store), &iter, 4, utf8, -1);
 	    if( utf8!=NULL )
